@@ -1,11 +1,11 @@
 #!/usr/bin/perl -w
-my $RCS_Id = '$Id: DB.pm,v 1.31 2006/01/22 16:33:12 jv Exp $ ';
+my $RCS_Id = '$Id: DB.pm,v 1.37 2006/02/07 11:46:28 jv Exp $ ';
 
 # Author          : Johan Vromans
 # Created On      : Sat May  7 09:18:15 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Sun Jan 22 15:19:01 2006
-# Update Count    : 258
+# Last Modified On: Tue Feb  7 12:28:53 2006
+# Update Count    : 309
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -21,8 +21,6 @@ use strict;
 use EB;
 use DBI;
 
-my $postgres = 1;		# PostgreSQL
-
 my $dbh;			# singleton for DB
 my $db;				# singleton for EBDB
 
@@ -367,26 +365,24 @@ sub adm_busy {
     $self->do("SELECT COUNT(*) FROM Journal")->[0];
 }
 
+################ API calls for database backend ################
+
+my $dbpkg;
+
 sub connectdb {
     my ($self, $nocheck) = @_;
 
     return $dbh if $dbh;
-
+    my $pkg = $dbpkg || $self->_loaddbbackend;
     my $dbname = $cfg->val(qw(database name));
-    croak("?INTERNAL ERROR: No database name") unless defined $dbname;;
-    $dbname = "eekboek_".$dbname unless $dbname =~ /^eekboek_/;
-    $dbname = "dbi:Pg:dbname=" . $dbname;
-
-    my $t;
-    $dbname .= ";host=" . $t if $t = $cfg->val(qw(database host), undef);
-    $dbname .= ";port=" . $t if $t = $cfg->val(qw(database port), undef);
-
-    my $dbuser = $cfg->val(qw(database user), undef);
-    my $dbpass = $cfg->val(qw(database password), undef);
-
-    $dbh = DBI::->connect($dbname, $dbuser, $dbpass)
-      or die("?".__x("Database verbindingsprobleem: {err}",
-		     err => $DBI::errstr)."\n");
+    croak("?INTERNAL ERROR: No database name") unless defined $dbname;
+    eval {
+	$dbh = $pkg->connect($dbname)
+	  or die("?".__x("Database verbindingsprobleem: {err}",
+			 err => $DBI::errstr)."\n");
+    };
+    die($@) if $@;
+    $dbpkg = $pkg;
     $dbh->{RaiseError} = 1;
     $dbh->{AutoCommit} = 0;
     $dbh->{ChopBlanks} = 1;
@@ -394,6 +390,74 @@ sub connectdb {
     $dbh;
 }
 
+sub disconnect {
+    my ($self) = shift;
+    $dbpkg ||= $self->_loaddbbackend;
+    $dbpkg->disconnect;
+    undef $dbh;
+}
+
+sub listdb {
+    my ($self) = shift;
+    $dbpkg ||= $self->_loaddbbackend;
+    $dbpkg->list;
+}
+
+sub cleardb {
+    my ($self) = shift;
+    $dbpkg ||= $self->_loaddbbackend;
+    $dbpkg->clear;
+    $self->resetdbcache;
+}
+
+sub createdb {
+    my ($self, $dbname) = @_;
+    $dbpkg ||= $self->_loaddbbackend;
+    Carp::confess("OOPS") unless $dbpkg;
+    $dbpkg->create($dbname);
+    $self->resetdbcache;
+}
+
+sub driverdb {
+    my ($self) = shift;
+    $dbpkg ||= $self->_loaddbbackend;
+    $dbpkg->type;
+}
+
+sub isql {
+    my ($self) = shift;
+    $dbpkg ||= $self->_loaddbbackend;
+    $dbpkg->isql(@_);
+}
+
+sub get_sequence {
+    my ($self) = shift;
+    $self->connectdb;
+    Carp::confess("OOPS") unless $dbpkg;
+    $dbpkg->get_sequence(@_);
+}
+
+sub set_sequence {
+    my ($self) = shift;
+    $self->connectdb;
+    $dbpkg->set_sequence(@_);
+}
+
+sub _loaddbbackend {
+    my ($self) = @_;
+    my $dbtype = $cfg->val(qw(database driver), "postgres");
+    my $pkg = __PACKAGE__ . "::" . ucfirst(lc($dbtype));
+    my $pkgfile = __PACKAGE__ . "::" . ucfirst(lc($dbtype)) . ".pm";
+    $pkgfile =~ s/::/\//g;
+    eval { require $pkgfile };
+    die("?".__x("Geen ondersteuning voor database type {db}",
+		db => $dbtype)."\n$@") if $@;
+    #Carp::cluck("Returning: $pkg");
+    return $pkg;
+}
+
+################ End API calls for database backend ################
+
 sub trace {
     my ($self, $value) = @_;
     my $cur = $trace;
@@ -431,15 +495,19 @@ END {
       if %sth && $cfg->val("internal sql", qw(prepstats), 0);
 }
 
-sub close {
+sub resetdbcache {
     my ($self) = @_;
-    $dbh->disconnect;
-    undef $dbh;
     %sth = ();
     $self->std_acc("");
     $self->adm("");
 }
 
+sub close {
+    my ($self) = @_;
+    $self->disconnectdb;
+    $self->resetdbcache;
+}
+
 sub show_sql($$@) {
     my ($self, $sql, @args) = @_;
     my @a = map {
@@ -480,25 +548,6 @@ sub get_value {
     return ($rr && defined($rr->[0]) ? $rr->[0] : undef);
 }
 
-sub get_sequence {
-    my ($self, $seq, $noinc) = @_;
-    my $sth = $self->sql_exec("SELECT ".
-			      ($noinc ? "currval" : "nextval").
-			      "('$seq')");
-    my $rr = $sth->fetchrow_arrayref;
-    $sth->finish;
-
-    return ($rr && defined($rr->[0]) ? $rr->[0] : undef);
-}
-
-sub set_sequence {
-    my ($self, $seq, $value) = @_;
-    # Init a sequence to value.
-    # The next call to get_sequence will return this value.
-    $self->sql_exec("SELECT setval('$seq', $value, false)")->finish;
-    $value;
-}
-
 sub do {
     my $self = shift;
     my $sql = shift;
