@@ -1,17 +1,18 @@
 #!/usr/bin/perl -w
-my $RCS_Id = '$Id: BTWAangifte.pm,v 1.23 2006/01/13 14:32:53 jv Exp $ ';
+my $RCS_Id = '$Id: BTWAangifte.pm,v 1.27 2006/02/03 14:00:24 jv Exp $ ';
 
 # Author          : Johan Vromans
 # Created On      : Tue Jul 19 19:01:33 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Fri Jan 13 15:32:37 2006
-# Update Count    : 403
+# Last Modified On: Fri Feb  3 14:33:01 2006
+# Update Count    : 457
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
 
 package main;
 
+our $cfg;
 our $dbh;
 
 package EB::Report::BTWAangifte;
@@ -23,6 +24,8 @@ use EB::Finance;
 
 use POSIX qw(floor ceil);
 
+my $trace = $cfg->val(__PACKAGE__, "trace", undef);
+
 my @periodetabel;
 
 sub new {
@@ -257,15 +260,6 @@ sub parse_periode {
 sub collect {
     my ($self, $begin, $end) = @_;
 
-    # Target: alle boekstukken van type 0 (inkoop/verkoop).
-    my $sth = $dbh->sql_exec
-      ("SELECT bsr_amount,bsr_acc_id,bsr_btw_id,bsr_btw_acc,rel_debcrd,rel_btw_status".
-       " FROM Boekstukregels, Relaties".
-       " WHERE bsr_rel_code = rel_code".
-       " AND bsr_date >= ? AND bsr_date <= ?".
-       " AND bsr_type = 0",
-       $begin, $end);
-
     my $v;
 
     my $tot = 0;
@@ -286,7 +280,9 @@ sub collect {
     my $deb_x = 0;
     my $deb_btw_x = 0;
 
-    # 1d. Belast met 0%/verlegd
+    # 1d. Eigen gebruikt.
+
+    # 1e. Belast met 0%/verlegd
 
     my $deb_0 = 0;
     my $verlegd = 0;
@@ -316,9 +312,32 @@ sub collect {
     my $crd_btw = 0;		# BTW betaald (voorheffingen)
     my $xx = 0;			# ongeclassificeerd (fout, dus)
 
+    # Target: alle boekstukken van type 0 (inkoop/verkoop).
+    my $sth = $dbh->sql_exec
+      ("SELECT bsr_amount,bsr_acc_id,bsr_btw_id,bsr_btw_acc,bsr_btw_class,rel_debcrd,rel_btw_status".
+       " FROM Boekstukregels, Relaties".
+       " WHERE bsr_rel_code = rel_code".
+       " AND bsr_date >= ? AND bsr_date <= ?".
+       " AND bsr_type = 0".
+       " UNION ALL ".
+       "SELECT bsr_amount,bsr_acc_id,bsr_btw_id,bsr_btw_acc,bsr_btw_class,null as rel_debcrd,0 as rel_btw_status".
+       " FROM Boekstukregels".
+       " WHERE bsr_rel_code IS NULL".
+       " AND bsr_date >= ? AND bsr_date <= ?".
+       " AND bsr_type = 0",
+       $begin, $end, $begin, $end);
+
     my $rr;
+
+    my $tr = $trace ? sub {
+	warn("BTW " . shift() . " @$rr\n");
+    } : sub {};
+
     while ( $rr = $sth->fetchrow_arrayref ) {
-	my ($amt, $acc, $btw_id, $btw_acc, $debcrd, $btw_status) = @$rr;
+	my ($amt, $acc, $btw_id, $btw_acc, $btwclass, $debcrd, $btw_status) = @$rr;
+
+	next unless $btwclass & BTWKLASSE_BTW_BIT;
+
 	my $btg_id = 0;
 	my $btw = 0;
 	$amt = -$amt;
@@ -329,36 +348,45 @@ sub collect {
 	    $amt = $a->[0] - ($btw = $a->[1]); # ex BTW
 	}
 
-	if ( $btw_status == BTW_NORMAAL ) {
+	unless ( defined $debcrd ) {
+	    $debcrd = !($btwclass & BTWKLASSE_IV_BIT);
+	}
+	if ( $btw_status == BTWTYPE_NORMAAL ) {
 	    if ( $debcrd ) {
-		if ( $btg_id == BTWTYPE_HOOG ) {
+		if ( $btg_id == BTWTARIEF_HOOG ) {
+		    $tr->("Hoog");
 		    $deb_h += $amt;
 		    $deb_btw_h += $btw;
 		}
-		elsif ( $btg_id == BTWTYPE_LAAG ) {
+		elsif ( $btg_id == BTWTARIEF_LAAG ) {
+		    $tr->("Laag");
 		    $deb_l += $amt;
 		    $deb_btw_l += $btw;
 		}
-		elsif ( $btg_id == BTWTYPE_GEEN ) {
-		    $deb_0 += $amt
-		      if $btw_acc;	# ???
+		elsif ( $btg_id == BTWTARIEF_GEEN ) {
+		    $tr->("0%");
+		    $deb_0 += $amt;
 		}
 		else {
+		    $tr->("Ander");
 		    $deb_x += $amt;
 		    $deb_btw_x += $btw;
 		}
 	    }
 	    else {
+		$tr->("Voorheffing");
 		$crd_btw -= $btw;
 	    }
 	}
-	elsif ( $btw_status == BTW_VERLEGD ) {
+	elsif ( $btw_status == BTWTYPE_VERLEGD ) {
 	    if ( $debcrd ) {
+		$tr->("Verlegd");
 		$verlegd += $amt;
 	    }
 	}
-	elsif ( $btw_status == BTW_INTRA ) {
+	elsif ( $btw_status == BTWTYPE_INTRA ) {
 	    if ( $debcrd ) {
+		$tr->("Intra");
 		$intra_deb += $amt;
 		$intra_deb_btw += $btw;
 	    }
@@ -367,16 +395,19 @@ sub collect {
 		$intra_crd_btw -= $btw;
 	    }
 	}
-	elsif ( $btw_status == BTW_EXTRA ) {
+	elsif ( $btw_status == BTWTYPE_EXTRA ) {
 	    if ( $debcrd ) {
+		$tr->("Extra D");
 		$extra_deb += $amt;
 	    }
 	    else {
+		$tr->("Extra C");
 		$extra_crd -= $amt;
 	    }
 	}
 	else {
 	    # Foutvanger.
+	    $tr->("????");
 	    $xx += $amt;
 	}
     }
@@ -400,8 +431,11 @@ sub collect {
     $data{deb_x} = $v;
     $tot += $v;
 
-    # 1d. Belast met 0%/verlegd
+    # 1d. Eigen gebruik
+
+    # 1e. Belast met 0%/verlegd
     $data{deb_0} = rounddown($deb_0 + $verlegd);
+    #$data{deb_0} = roundtozero($deb_0 + $verlegd);
 
     # Buitenland
     # 3. Door mij verrichte leveringen
@@ -439,10 +473,17 @@ sub collect {
     $data{vb} = $vb;
     $tot -= $vb;
 
-    # 5c Subtotaal
-    $data{sub1} = $tot;
+    # 5c Subtotaal / 5g Totaal
+    $data{sub1} = $data{tot} = $tot;
     $data{onbekend} = $xx if $xx;
 
+    # 5d Kleine Ondernemers
+    if ( $self->{compat_periode} =~ /^\d\d\d\d$/ ) { # aangifte per jaar
+	if ( $data{ko} = kleine_ondernemers($self->{compat_periode}, $data{sub1}) ) {
+	    $data{tot} -= $data{ko};
+	}
+    }
+
     $data{btw_delta} = $btw_delta if $btw_delta;
 
     return \%data;
@@ -473,8 +514,10 @@ sub report {
     # 1c. Belast met ander, niet-nul tarief
     $rep->outline('', "1c", "Belast met ander tarief", $data->{deb_x}, $data->{deb_btw_x});
 
-    # 1d. Belast met 0%/verlegd
-    $rep->outline('', "1d", "Belast met 0% / verlegd", $data->{deb_0}, undef);
+    # 1d. Eigen gebruik
+
+    # 1e. Belast met 0%/verlegd
+    $rep->outline('', "1e", "Belast met 0% / verlegd", $data->{deb_0}, undef);
 
     # Buitenland
     $rep->outline('H1', "Buitenland");
@@ -511,6 +554,23 @@ sub report {
     # 5c Subtotaal
     $rep->outline('', "5c", "Subtotaal", undef, $data->{sub1});
 
+    if ( $self->{compat_periode} =~ /^\d\d\d\d$/ ) { # aangifte per jaar
+	if ( defined($data->{ko}) ) {
+	    # 5d Subtotaal
+	    $rep->outline('', "5d", "Vermindering kleineondernemersregeling", undef, $data->{ko});
+	}
+	else {
+	    $rep->outline('', "5d", "Geen gegevens voor kleineondernemersregeling", undef, undef);
+	}
+    }
+
+    # 5g Subtotaal
+    if ( $data->{tot} >= 0 ) {
+	$rep->outline('', "5g", "Totaal te betalen", undef, $data->{tot});
+    }
+    else {
+	$rep->outline('', "5g", "Totaal terug te vragen", undef, 0-$data->{tot});
+    }
     $rep->outline('X', "xx", "Onbekend", undef, numfmt($data->{onbekend})) if $data->{onbekend};
 
     my @msg;
@@ -521,11 +581,7 @@ sub report {
 		 " Voor de aangifte is de werkelijk ingehouden BTW gebruikt.",
 		 amount => numfmt($data->{btw_delta})));
     }
-    if ( $self->{compat_periode} =~ /^\d\d\d\d$/ ) { # aangifte per jaar
-	if ( my $msg = kleine_ondernemers($self->{compat_periode}, $data->{sub1}) ) {
-	    push(@msg, $msg);
-	}
-    }
+
     $rep->finish(@msg);
 
 }
@@ -558,26 +614,37 @@ sub roundup {
     $vb;
 }
 
+sub roundtozero {
+    my ($vb) = @_;
+    return 0 unless $vb;
+    $vb /= AMTSCALE;
+    if ( $vb >= 0 ) {
+	$vb = floor($vb);
+    }
+    else {
+	$vb = 0-floor(abs($vb));
+    }
+    $vb;
+}
+
 sub kleine_ondernemers {
     my ($year, $amount) = @_;
 
-    return if $amount < 0;
+    return 0 if $amount < 0;
 
     # Formule lijkt linds 1995 ongwijzigd, alleen de bedragen veranderen.
     my %mmtab = ( 2005 => [ 1345, 1883 ] );
 
-    return "" unless exists $mmtab{$year};
+    return unless exists $mmtab{$year};
 
     my ($min, $max) = @{$mmtab{$year}};
     if ( $amount <= $min ) {
-	return __x("Het te betalen bedrag is minder dan {ko} en hoeft niet te worden betaald (Regeling Kleine Ondernemers).", ko => $min)."\n";
+	return $amount;
     }
     elsif ( $amount > $min && $amount <= $max ) {
-	return __x("Het te betalen bedrag is minder dan {ko}. U hoeft slechts {amt} te betalen (Regeling Kleine Ondernemers).",
-		   ko => $max,
-		   amt => $amount - (2.5 * ($max - $amount)))."\n";
+	return roundup(250 * ($max - $amount));
     }
-    return "";
+    return 0;
 }
 
 package EB::Report::BTWAangifte::Text;
