@@ -1,11 +1,10 @@
-#!/usr/bin/perl -w
-my $RCS_Id = '$Id: Schema.pm,v 1.26 2006/01/22 16:47:53 jv Exp $ ';
+my $RCS_Id = '$Id: Schema.pm,v 1.31 2006/02/07 11:44:05 jv Exp $ ';
 
 # Author          : Johan Vromans
 # Created On      : Sun Aug 14 18:10:49 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Fri Jan 20 21:53:37 2006
-# Update Count    : 454
+# Last Modified On: Tue Feb  7 12:20:08 2006
+# Update Count    : 478
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -56,14 +55,20 @@ sub create {
     shift;			# singleton class method
     my ($name) = @_;
     my $file;
-    foreach my $dir ( ".", "schema" ) {
-	foreach my $ext ( ".dat" ) {
-	    next unless -s "$dir/$name$ext";
-	    $file = "$dir/$name$ext";
-	    last;
-	}
+    if ( $name !~ /^\w+$/) {
+	$file = $name;
     }
-    $file = findlib("schema/$name.dat") unless $file;
+    else {
+	foreach my $dir ( ".", "schema" ) {
+	    foreach my $ext ( ".dat" ) {
+		next unless -s "$dir/$name$ext";
+		$file = "$dir/$name$ext";
+		last;
+	    }
+	}
+	$file = findlib("schema/$name.dat") unless $file;
+    }
+
     die("?".__x("Onbekend schema: {schema}", schema => $name)."\n") unless $file;
     open($fh, "<$file") or die("?".__x("Toegangsfout schema data: {err}", err => $!)."\n");
     $schema = $name;
@@ -84,9 +89,24 @@ my %dbk;			# dagboeken
 my @dbk;			# dagboeken
 my @btw;			# btw tarieven
 my %btwmap;			# btw type/incl -> code
-
 my $fail;			# any errors
 
+sub init_vars {
+    @hvdi = ();			# hoofdverdichtingen
+    @vdi = ();			# verdichtingen
+    undef $max_hvd;		# hoogste waarde voor hoofdverdichting
+    undef $max_vrd;		# hoogste waarde voor verdichting
+    %acc = ();			# grootboekrekeningen
+    undef $chvdi;		# huidige hoofdverdichting
+    undef $cvdi;		# huidige verdichting
+    %std = ();			# standaardrekeningen
+    %dbk = ();			# dagboeken
+    @dbk = ();			# dagboeken
+    @btw = ();			# btw tarieven
+    %btwmap = ();		# btw type/incl -> code
+    undef $fail;		# any errors
+}
+
 sub error { warn('?', @_); $fail++; }
 
 my $dbkid;
@@ -127,7 +147,7 @@ sub scan_dagboeken {
     error(__x("Dagboek {id}: het :rekening nummer ontbreekt", id => $id)."\n")
       if ( $type == DBKTYPE_KAS || $type == DBKTYPE_BANK ) and !$type;
     error(__x("Dagboek {id}: rekeningnummer enkel toegestaan voor Kas en Bankboeken", id => $id)."\n")
-      if $rek && !($type == DBKTYPE_KAS || $type == DBKTYPE_BANK);
+      if $rek && !($type == DBKTYPE_KAS || $type == DBKTYPE_BANK || $type == DBKTYPE_MEMORIAAL);
 
     $dbk{$id} = $dbkid;
     $dbk[$dbkid] = [ $id, $desc, $type, $rek||undef ];
@@ -156,13 +176,13 @@ sub scan_btw {
 	    }
 	}
 	elsif ( $extra =~ m/^tariefgroep=hoog$/i ) {
-	    $groep = BTWTYPE_HOOG;
+	    $groep = BTWTARIEF_HOOG;
 	}
 	elsif ( $extra =~ m/^tariefgroep=laag$/i ) {
-	    $groep = BTWTYPE_LAAG;
+	    $groep = BTWTARIEF_LAAG;
 	}
 	elsif ( $extra =~ m/^tariefgroep=geen$/i ) {
-	    $groep = BTWTYPE_GEEN;
+	    $groep = BTWTARIEF_GEEN;
 	}
 	elsif ( $extra =~ m/^incl(?:usief)?$/i ) {
 	    $incl = 1;
@@ -178,18 +198,18 @@ sub scan_btw {
 
     error(__x("BTW tarief {id}: geen percentage en de tariefgroep is niet \"{none}\"",
 	      id => $id, none => _T("geen"))."\n")
-      unless defined($perc) || $groep == BTWTYPE_GEEN;
+      unless defined($perc) || $groep == BTWTARIEF_GEEN;
 
     $btw[$id] = [ $id, $desc, $groep, $perc, $incl ];
 
-    if ( $groep == BTWTYPE_GEEN && !defined($btwmap{g}) ) {
+    if ( $groep == BTWTARIEF_GEEN && !defined($btwmap{g}) ) {
 	$btwmap{g} = $id;
     }
     elsif ( $incl ) {
-	if ( $groep == BTWTYPE_HOOG && !defined($btwmap{h}) ) {
+	if ( $groep == BTWTARIEF_HOOG && !defined($btwmap{h}) ) {
 	    $btwmap{h} = $id;
 	}
-	elsif ( $groep == BTWTYPE_LAAG && !defined($btwmap{l}) ) {
+	elsif ( $groep == BTWTARIEF_LAAG && !defined($btwmap{l}) ) {
 	    $btwmap{l} = $id;
 	}
     }
@@ -213,7 +233,7 @@ sub scan_balres {
 	error(__x("Dubbel: rekening {acct}", acct => $1)."\n") if exists($acc{$id});
 	error(__x("Rekening {id} heeft geen verdichting", id => $id)."\n") unless defined($cvdi);
 	my $debcrd;
-	my $kstomz;
+	my $kstomz = 1;
 	if ( ($balres ? $flags =~ /^[dc]$/i : $flags =~ /^[ko]$/i)
 	     ||
 	     $flags =~ /^[dc][ko]$/i ) {
@@ -266,6 +286,7 @@ sub scan_result {
 
 sub load_schema {
 
+    init_vars();
     my $scanner;		# current scanner
     $max_hvd = 9;
     $max_vrd = 99;
@@ -276,6 +297,7 @@ sub load_schema {
 	next if /^\s*#/;
 	next unless /\S/;
 
+	# Scanner selectie.
 	if ( /^balans/i ) {
 	    $scanner = \&scan_balans;
 	    next;
@@ -292,11 +314,15 @@ sub load_schema {
 	    $scanner = \&scan_btw;
 	    next;
 	}
+
+	# Overige settings.
 	if ( /^verdichting\s+(\d+)\s+(\d+)/i && $1 < $2 ) {
 	    $max_hvd = $1;
 	    $max_vrd = $2;
 	    next;
 	}
+
+	# Anders: Scan.
 	if ( $scanner ) {
 	    chomp;
 	    $scanner->() or
@@ -358,7 +384,7 @@ sub sql_eekboek {
       or die("?"._T("Installatiefout -- geen schema")."\n");
 
     local $/;
-    $sql = <$fh>;
+    my $sql = <$fh>;
     close($fh);
     $sql;
 }
@@ -443,7 +469,7 @@ ESQL
 
     foreach ( @btw ) {
 	next unless defined;
-	if ( $_->[2] == BTWTYPE_GEEN ) {
+	if ( $_->[2] == BTWTARIEF_GEEN ) {
 	    $_->[3] = 0;
 	    $_->[4] = "\\N";
 	}
@@ -494,6 +520,10 @@ sub _tf {
     qw(f t)[shift];
 }
 
+sub _tfn {
+    defined($_[0]) ? qw(f t)[$_[0]] : "\\N";
+}
+
 ################ Subroutines ################
 
 sub dump_sql {
@@ -572,8 +602,24 @@ print {$fh}  <<EOD;
 #   winst	rekening waarop de winst wordt geboekt
 #
 # Al deze koppelingen moeten nmaal in het rekeningschema voorkomen.
+
 EOD
 
+=begin not_now
+
+# De classificatie Kosten/Omzet voor resultaatrekeningen wordt onder
+# meer gebruikt om te bepalen hoe BTW moet worden geboekt. Als om
+# welke reden dan ook de classificatie niet betrouwbaar moet worden
+# geacht, kan de aanduiding "Kosten-Omzet NOK" worden gebruikt om aan
+# te geven dat EekBoek deze niet mag gebruiken. Dit kan echter leiden
+# tot problemen met BTW boekingen!
+
+EOD
+
+    print {$fh} ($dbh->adm_ko ? "# " : "", "Kosten-Omzet NOK\n");
+
+=cut
+
 $max_hvd = $dbh->do("SELECT MAX(vdi_id) FROM Verdichtingen WHERE vdi_struct IS NULL")->[0];
 $max_vrd = $dbh->do("SELECT MAX(vdi_id) FROM Verdichtingen WHERE NOT vdi_struct IS NULL")->[0];
 
@@ -680,16 +726,20 @@ sub dump_acc {
 	    while ( my $rr = $sth->fetchrow_arrayref ) {
 		my ($id, $desc, $acc_balres, $acc_debcrd, $acc_kstomz, $btw_id, $btw, $btwincl) = @$rr;
 		my $flags = "";
-		$flags .= $acc_debcrd ? "D" : "C" if $balres;
-		$flags .= $acc_kstomz ? "K" : "O" unless $balres;
+		if ( $balres ) {
+		    $flags .= $acc_debcrd ? "D" : "C";
+		}
+		else {
+		    $flags .= $acc_kstomz ? "K" : "O";
+		}
 		my $extra = "";
-		if ( $btw == BTWTYPE_HOOG && $btwincl ) {
+		if ( $btw == BTWTARIEF_HOOG && $btwincl ) {
 		    $extra .= " :btw=hoog";
 		}
-		elsif ( $btw == BTWTYPE_LAAG && $btwincl ) {
+		elsif ( $btw == BTWTARIEF_LAAG && $btwincl ) {
 		    $extra .= " :btw=laag";
 		}
-		elsif ( $btw != BTWTYPE_GEEN ) {
+		elsif ( $btw != BTWTARIEF_GEEN ) {
 		    $extra .= " :btw=$btw_id";
 		}
 		$extra .= " :koppeling=".$kopp{$id} if exists($kopp{$id});
@@ -718,8 +768,8 @@ sub dump_btw {
     while ( my $rr = $sth->fetchrow_arrayref ) {
 	my ($id, $desc, $perc, $btg, $incl) = @$rr;
 	my $extra = "";
-	$extra .= " :tariefgroep=" . lc(BTWTYPES->[$btg]);
-	if ( $btg != BTWTYPE_GEEN ) {
+	$extra .= " :tariefgroep=" . lc(BTWTARIEVEN->[$btg]);
+	if ( $btg != BTWTARIEF_GEEN ) {
 	    $extra .= " :perc=".btwfmt($perc);
 	    $extra .= " :" . qw(exclusief inclusief)[$incl] unless $incl;
 	}
